@@ -1,6 +1,6 @@
 // CoreConfig.cc --- The WorkRave Core Configuration
 //
-// Copyright (C) 2007, 2008, 2009 Rob Caelers & Raymond Penners
+// Copyright (C) 2007, 2008, 2009, 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -52,7 +52,7 @@ const string CoreConfig::CFG_KEY_MONITOR_ACTIVITY          = "monitor/activity";
 const string CoreConfig::CFG_KEY_MONITOR_IDLE              = "monitor/idle";
 
 const string CoreConfig::CFG_KEY_GENERAL_DATADIR           = "general/datadir";
-const string CoreConfig::CFG_KEY_OPERATION_MODE            = "gui/operation-mode";
+const string CoreConfig::CFG_KEY_OPERATION_MODE            = "general/operation-mode";
 const string CoreConfig::CFG_KEY_USAGE_MODE                = "general/usage-mode";
 
 const string CoreConfig::CFG_KEY_DISTRIBUTION              = "distribution";
@@ -71,7 +71,7 @@ bool
 CoreConfig::match(const std::string &str, const std::string &key, workrave::BreakId &id)
 {
   bool ret = false;
-  
+
   for (int i = 0; !ret && i < BREAK_ID_SIZEOF; i++)
     {
       if (key % BreakId(i) == str)
