@@ -1,6 +1,6 @@
 // DistributionManager.cc
 //
-// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010, 2011 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -515,7 +515,7 @@ DistributionManager::read_configuration()
     {
       string peer ;
       is_set = configurator->get_value(CoreConfig::CFG_KEY_DISTRIBUTION_PEERS, peer);
-      if (is_set)
+      if (is_set && peer != "")
         {
           parse_peers(peer);
         }
@@ -548,6 +548,7 @@ void
 DistributionManager::config_changed_notify(const string &key)
 {
   TRACE_ENTER_MSG("DistributionManager:config_changed_notify", key);
+  (void)key;
 
   read_configuration();
 
@@ -555,7 +556,7 @@ DistributionManager::config_changed_notify(const string &key)
 }
 
 
-//! 
+//!
 void
 DistributionManager::log(const char *fmt, ...)
 {
