@@ -28,6 +28,7 @@
 
 #include <iostream>
 #include <fstream>
+#include <algorithm>
 
 #include "nls.h"
 
@@ -46,6 +47,10 @@
 
 #include "Util.hh"
 
+#ifdef PLATFORM_OS_WIN32
+#include "win32/ghmac.h"
+#endif
+
 using namespace std;
 
 //! Construct a new socket link.
@@ -988,7 +993,7 @@ DistributionSocketLink::init_packet(PacketBuffer &packet, PacketCommand cmd)
   // Length.
   packet.pack_ushort(0);
   // Version
-  packet.pack_byte(2);
+  packet.pack_byte(3);
   // Flags
   packet.pack_byte(0);
   // Command
@@ -1188,8 +1193,13 @@ DistributionSocketLink::process_client_packet(Client *client)
     {
       switch (type)
         {
-        case PACKET_HELLO:
-          handle_hello(packet, source);
+        case PACKET_HELLO1:
+          handle_hello1(packet, source);
+          forward = false;
+          break;
+
+        case PACKET_HELLO2:
+          handle_hello2(packet, source);
           forward = false;
           break;
 
@@ -1228,14 +1238,20 @@ DistributionSocketLink::process_client_packet(Client *client)
           break;
         }
 
-      if (forward)
+      if (forward &&
+          find(clients.begin(), clients.end(), client) != clients.end())
         {
           forward_packet_except(packet, client, source);
         }
     }
 
-  packet.clear();
-  packet.resize(0);
+  if (find(clients.begin(), clients.end(), client) != clients.end())
+    {
+      // hack... client may have been removed...
+      packet.clear();
+      packet.resize(0);
+    }
+  
   TRACE_EXIT();
 }
 
@@ -1278,23 +1294,39 @@ DistributionSocketLink::forward_packet(PacketBuffer &packet, Client *dest, Clien
   TRACE_EXIT();
 }
 
+string
+DistributionSocketLink::get_random_string() const
+{
+  static const char alphanum[] = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
+  std::string rnd;
+  
+  for (int i = 0; i < 100; ++i)
+    {
+      rnd += alphanum[g_random_int_range(0, sizeof(alphanum) - 1)];
+    }
+  
+  return rnd;
+}
 
 //! Sends a hello to the specified client.
 void
-DistributionSocketLink::send_hello(Client *client)
+DistributionSocketLink::send_hello1(Client *client)
 {
-  TRACE_ENTER("DistributionSocketLink::send_hello");
-
+  TRACE_ENTER("DistributionSocketLink::send_hello1");
+  
   PacketBuffer packet;
-
+  
   packet.create();
-  init_packet(packet, PACKET_HELLO);
+  init_packet(packet, PACKET_HELLO1);
+  
+  string rnd = get_random_string();
+  client->challenge = rnd;
 
+  TRACE_MSG(username << " " << get_my_id() << " " << rnd);
+  
   packet.pack_string(username);
-  packet.pack_string(password);
   packet.pack_string(get_my_id());
-  packet.pack_string(get_my_id()); // was: hostname
-  packet.pack_ushort(server_port);
+  packet.pack_string(rnd);
 
   send_packet(client, packet);
   TRACE_EXIT();
@@ -1303,20 +1335,87 @@ DistributionSocketLink::send_hello(Client *client)
 
 //! Handles a Hello from the specified client.
 void
-DistributionSocketLink::handle_hello(PacketBuffer &packet, Client *client)
+DistributionSocketLink::handle_hello1(PacketBuffer &packet, Client *client)
 {
-  TRACE_ENTER("DistributionSocketLink::handle_hello");
+  TRACE_ENTER("DistributionSocketLink::handle_hello1");
+  
+  gchar *user = packet.unpack_string();
+  gchar *id = packet.unpack_string();
+  gchar *rnd = packet.unpack_string();
+
+  TRACE_MSG(user << " " << id << " " << rnd);
+  
+  dist_manager->log(_("Client %s saying hello."), id != NULL ? id : "Unknown");
+  
+  if (user != NULL &&  (username == NULL || (strcmp(username, user) == 0)))
+    {
+      send_hello2(client, rnd);
+    }
+  else
+    {
+      // Incorrect user.
+      dist_manager->log(_("Client %s access denied."),
+                        id != NULL ? id : "Unknown");
+      remove_client(client);
+    }
+  
+  g_free(user);
+  g_free(id);
+  g_free(rnd);
+  
+  TRACE_EXIT();
+}
+
+//! Sends a hello to the specified client.
+void
+DistributionSocketLink::send_hello2(Client *client, gchar *rnd)
+{
+  TRACE_ENTER_MSG("DistributionSocketLink::send_hello2", username << " " << rnd << " " << get_my_id());
+  
+  PacketBuffer packet;
+
+  packet.create();
+  init_packet(packet, PACKET_HELLO2);
+  
+  GHmac *hmac = g_hmac_new(G_CHECKSUM_SHA1, (const guchar *)password, strlen(password));
+
+  g_hmac_update(hmac, (const guchar *)username, strlen(username));
+  g_hmac_update(hmac, (const guchar *)rnd, strlen(rnd));
+  g_hmac_update(hmac, (const guchar *)get_my_id().c_str(), get_my_id().length());
+
+  packet.pack_string(username);
+  packet.pack_string(g_hmac_get_string(hmac));
+  packet.pack_string(get_my_id());
+
+  g_hmac_unref (hmac);
+
+  send_packet(client, packet);
+  TRACE_EXIT();
+}
+
+
+//! Handles a Hello from the specified client.
+void
+DistributionSocketLink::handle_hello2(PacketBuffer &packet, Client *client)
+{
+  TRACE_ENTER("DistributionSocketLink::handle_hello2");
 
   gchar *user = packet.unpack_string();
   gchar *pass = packet.unpack_string();
   gchar *id = packet.unpack_string();
-  /* gchar *name = */ packet.unpack_string();
-  /* int port = */ packet.unpack_ushort();
 
+  TRACE_MSG(user << " " << pass << " " << id << " " << client->challenge);
+  
   dist_manager->log(_("Client %s saying hello."), id != NULL ? id : "Unknown");
 
-  if ( (username == NULL || (user != NULL && strcmp(username, user) == 0)) &&
-       (password == NULL || (pass != NULL && strcmp(password, pass) == 0)))
+  GHmac *hmac = g_hmac_new(G_CHECKSUM_SHA1, (const guchar *)password, strlen(password));
+  g_hmac_update(hmac, (const guchar *)username, strlen(username));
+  g_hmac_update(hmac, (const guchar *)client->challenge.c_str(), client->challenge.length());
+  g_hmac_update(hmac, (const guchar *)id, strlen(id));
+
+  if ( user != NULL && pass != NULL &&
+       (username == NULL || (strcmp(username, user) == 0)) &&
+       (password == NULL || (strcmp(g_hmac_get_string(hmac), pass) == 0)))
     {
       bool ok = set_client_id(client, id);
 
@@ -1324,6 +1423,7 @@ DistributionSocketLink::handle_hello(PacketBuffer &packet, Client *client)
         {
           // Welcome!
           send_welcome(client);
+          client->welcome = true;
         }
       else
         {
@@ -1347,11 +1447,11 @@ DistributionSocketLink::handle_hello(PacketBuffer &packet, Client *client)
   g_free(id);
   g_free(pass);
 
+  g_hmac_unref (hmac);
+
   TRACE_EXIT();
 }
-
-
-
+  
 //! Sends a hello to the specified client.
 void
 DistributionSocketLink::send_signoff(Client *to, Client *signedoff_client)
@@ -1394,7 +1494,10 @@ DistributionSocketLink::handle_signoff(PacketBuffer &packet, Client *client)
 {
   TRACE_ENTER("DistributionSocketLink::handle_signoff");
 
-  (void) client;
+  if (!client->welcome)
+    {
+      return;
+    }
 
   gchar *id = packet.unpack_string();
   Client *c = NULL;
@@ -1504,6 +1607,8 @@ DistributionSocketLink::handle_welcome(PacketBuffer &packet, Client *client)
 
   if (ok)
     {
+      client->welcome = true;
+      
       // The connected client offers the master client.
       // This info will be received in the client list.
       // So, we no longer know who's master...
@@ -1613,6 +1718,12 @@ DistributionSocketLink::handle_client_list(PacketBuffer &packet, Client *client,
 {
   TRACE_ENTER("DistributionSocketLink::handle_client_list");
 
+  if (!client->welcome)
+    {
+      TRACE_EXIT();
+      return false;;
+    }
+  
   // Extract data.
   gint num_clients = packet.unpack_ushort();
   gint flags = packet.unpack_ushort();
@@ -1770,6 +1881,12 @@ DistributionSocketLink::handle_claim(PacketBuffer &packet, Client *client)
 {
   TRACE_ENTER("DistributionSocketLink::handle_claim");
 
+  if (!client->welcome)
+    {
+      TRACE_EXIT();
+      return;
+    }
+  
   /*gint count = */ packet.unpack_ushort();
 
   if (i_am_master && master_locked)
@@ -1829,6 +1946,12 @@ DistributionSocketLink::handle_claim_reject(PacketBuffer &packet, Client *client
   TRACE_ENTER("DistributionSocketLink::handle_claim");
   (void) packet;
 
+  if (!client->welcome)
+    {
+      TRACE_EXIT();
+      return;
+    }
+  
   if (client != master_client)
     {
       dist_manager->log(_("Non-master client %s rejected master request."),
@@ -1889,7 +2012,6 @@ DistributionSocketLink::send_new_master(Client *client)
     }
 
   TRACE_EXIT();
-
 }
 
 
@@ -1899,6 +2021,12 @@ DistributionSocketLink::handle_new_master(PacketBuffer &packet, Client *client)
 {
   TRACE_ENTER("DistributionSocketLink::handle_new_master");
 
+  if (!client->welcome)
+    {
+      TRACE_EXIT();
+      return;
+    }
+  
   for (list<Client *>::iterator i = clients.begin(); i != clients.end(); i++)
     {
       (*i)->reject_count = 0;
@@ -1971,8 +2099,13 @@ void
 DistributionSocketLink::handle_client_message(PacketBuffer &packet, Client *client)
 {
   TRACE_ENTER("DistributionSocketLink:handle_client_message");
-  (void) client;
 
+  if (!client->welcome)
+    {
+      TRACE_EXIT();
+      return;
+    }
+  
   bool will_i_become_master = false;
 
   // dist_manager->log(_("Reveived client message from client %s:%d."), client->hostname, client->port);
@@ -2073,6 +2206,8 @@ DistributionSocketLink::socket_accepted(ISocketServer *scon, ISocket *ccon)
       ccon->set_data(client);
       ccon->set_listener(this);
       clients.push_back(client);
+
+      send_hello1(client);
     }
   TRACE_EXIT();
 }
@@ -2184,8 +2319,6 @@ DistributionSocketLink::socket_connected(ISocket *con, void *data)
   client->outbound = true;
   client->socket = con;
 
-  send_hello(client);
-
   TRACE_EXIT();
 }
 
