@@ -1,6 +1,6 @@
 // Timer.cc --- break timer
 //
-// Copyright (C) 2001 - 2010 Rob Caelers <robc@krandor.nl>
+// Copyright (C) 2001 - 2012 Rob Caelers <robc@krandor.nl>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -112,7 +112,7 @@ Timer::enable()
           elapsed_idle_time = autoreset_interval;
         }
 
-      if (get_elapsed_time() >= limit_interval)
+      if (limit_enabled && get_elapsed_time() >= limit_interval)
         {
           // Break is overdue, force a snooze.
           last_limit_time = core->get_time();
@@ -158,8 +158,11 @@ Timer::disable()
 void
 Timer::set_limit_enabled(bool b)
 {
-  limit_enabled = b;
-  compute_next_limit_time();
+  if (limit_enabled != b)
+    {
+      limit_enabled = b;
+      compute_next_limit_time();
+    }
 }
 
 
@@ -249,7 +252,7 @@ void
 Timer::set_activity_sensitive(bool a)
 {
   TRACE_ENTER_MSG("Timer::set_activity_sensitive", a);
-  
+
   activity_sensitive = a;
   activity_state = ACTIVITY_UNKNOWN;
 
@@ -259,7 +262,7 @@ Timer::set_activity_sensitive(bool a)
       // it has some elasped time. Otherwise a daily limit
       // will never start (well, not until it resets...)
       time_t elasped = get_elapsed_time();
-      if (elasped > 0 && elasped < limit_interval)
+      if (elasped > 0 && (elasped < limit_interval || !limit_enabled))
         {
           activity_state = ACTIVITY_ACTIVE;
         }
@@ -410,7 +413,7 @@ Timer::reset_timer()
 
   // Update total overdue.
   time_t elapsed = get_elapsed_time();
-  if (elapsed > limit_interval)
+  if (limit_enabled && elapsed > limit_interval)
     {
       total_overdue_time += (elapsed - limit_interval);
     }
@@ -464,13 +467,13 @@ Timer::start_timer()
       // Set last start and stop times.
       if (!timer_frozen)
         {
-          TRACE_MSG("!Frozen");
           // Timer is not frozen, so let's start.
           last_start_time = core->get_time();
           elapsed_idle_time = 0;
         }
       else
         {
+          TRACE_MSG("timer is frozen.");
           // The timer is frozen, so we don't start counting 'active' time.
           // Instead, update the elapsed idle time.
           if (last_stop_time != 0)
@@ -488,7 +491,6 @@ Timer::start_timer()
       timer_state = STATE_RUNNING;
 
       // When to generate a limit-reached-event.
-      TRACE_MSG("Compute");
       compute_next_limit_time();
     }
   TRACE_EXIT();
@@ -631,7 +633,7 @@ Timer::get_elapsed_time() const
   time_t ret = elapsed_time;
 
   TRACE_MSG(ret << " " << core->get_time() << " " <<  last_start_time);
-    
+
   if (timer_enabled && last_start_time != 0)
     {
       ret += (core->get_time() - last_start_time);
@@ -650,8 +652,8 @@ Timer::get_total_overdue_time() const
   time_t elapsed = get_elapsed_time();
 
   TRACE_MSG(ret << " " << elapsed);
-  
-  if (elapsed > limit_interval)
+
+  if (limit_enabled && elapsed > limit_interval)
     {
       ret += (elapsed - limit_interval);
     }
@@ -705,20 +707,20 @@ void
 Timer::process(ActivityState new_activity_state, TimerInfo &info)
 {
   TRACE_ENTER_MSG("Timer::Process", timer_id << timer_id << " " << new_activity_state);
-  
+
   // msvc can't handle std::string conditional tracepoints. use TRACE as the conditional
   bool TRACE = ( timer_id == "micro_pause" || timer_id == "rest_break" );
   (void) TRACE;
-  
+
   time_t current_time= core->get_time();
-  
+
   // Default event to return.
   info.event = TIMER_EVENT_NONE;
   info.idle_time = get_elapsed_idle_time();
   info.elapsed_time = get_elapsed_time();
-  
-  TRACE_MSG("idle = " << info.idle_time);
-  TRACE_MSG("elap = " << info.elapsed_time);
+
+  TRACE_MSG("idle_time = " << info.idle_time);
+  TRACE_MSG("elapsed_time = " << info.elapsed_time);
   TRACE_MSG("enabled = " << timer_enabled);
   TRACE_MSG("last_start_time " << last_start_time);
   TRACE_MSG("next_pred_reset_time " << next_pred_reset_time);
@@ -733,8 +735,7 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
       new_activity_state = activity_monitor->get_current_state();
       TRACE_MSG("foreign activity state =" << new_activity_state);
     }
-  
-  if (activity_sensitive)
+  else if (activity_sensitive)
     {
       // This timer responds to the activity monitoring.
       TRACE_MSG("is activity sensitive");
@@ -746,9 +747,9 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
       TRACE_MSG("is not activity sensitive");
       if (activity_state != ACTIVITY_UNKNOWN)
         {
-          TRACE_MSG("as = "   << activity_state <<
-                    " nas = " << new_activity_state <<
-                    " el ="   << get_elapsed_time());
+          TRACE_MSG("activity_state = "   << activity_state <<
+                    " new_activity_state = " << new_activity_state <<
+                    " elapsed_time ="   << get_elapsed_time());
 
           if (insensitive_mode == INSENSITIVE_MODE_IDLE_ALWAYS)
             // Forces ACTIVITY_IDLE every time, regardless of sensitivity
@@ -761,19 +762,14 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
             {
               if (insensitive_mode == INSENSITIVE_MODE_IDLE_ON_LIMIT_REACHED)
                 {
+                  TRACE_MSG("MODE_IDLE_ON_LIMIT_REACHED");
                   new_activity_state = activity_state;
                 }
 
-              TRACE_MSG("new state2 = " << activity_state << " " << new_activity_state);
+              TRACE_MSG("new_activity_state = " << new_activity_state);
             }
 
-          TRACE_MSG("state = " << new_activity_state);
-          TRACE_MSG("time, next limit "
-                    << current_time << " "
-                    << next_limit_time << " "
-                    << limit_interval << " "
-                    << (next_limit_time - current_time)
-                    );
+          TRACE_MSG("activity_state = " << new_activity_state);
         }
     }
 
@@ -832,7 +828,7 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
 
       info.event = TIMER_EVENT_LIMIT_REACHED;
       // Its very unlikely (but not impossible) that this will overrule
-      // the EventStarted. Hey, shit happends.
+      // the EventStarted. Hey, shit happens.
 
       if (!activity_sensitive)
         {
@@ -846,7 +842,7 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
 
       next_reset_time = 0;
 
-      bool natural = (limit_interval >=  get_elapsed_time());
+      bool natural = limit_enabled && limit_interval >= get_elapsed_time();
 
       reset_timer();
 
@@ -911,7 +907,7 @@ Timer::deserialize_state(const std::string &state, int version)
       ss >> tz;
       tz -= timezone;
     }
-  
+
   // Sanity check...
   if (lastReset > saveTime)
     {
@@ -942,7 +938,7 @@ Timer::deserialize_state(const std::string &state, int version)
     }
 
   // overdue, so snooze
-  if (get_elapsed_time() >= limit_interval)
+  if (limit_enabled && get_elapsed_time() >= limit_interval)
     {
       last_limit_time = llt;
       last_limit_elapsed = lle;
@@ -982,12 +978,12 @@ Timer::set_state(int elapsed, int idle, int overdue)
   if (overdue != -1)
     {
       total_overdue_time = overdue;
-      if (get_elapsed_time() > limit_interval)
+      if (limit_enabled && get_elapsed_time() > limit_interval)
         {
           total_overdue_time -= (get_elapsed_time() - limit_interval);
         }
     }
-  
+
   compute_next_reset_time();
   compute_next_limit_time();
   compute_next_predicate_reset_time();
