@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright (C) 2007, 2008, 2009 Rob Caelers <robc@krandor.nl>
+# Copyright (C) 2007, 2008, 2009, 2011 Rob Caelers <robc@krandor.nl>
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,7 @@ from xml.dom.minidom import parse
 class NodeBase(object):
     pass
 
+
 class ArgNode(NodeBase):
     def __init__(self, interface_node):
         NodeBase.__init__(self)
@@ -43,6 +44,7 @@ class ArgNode(NodeBase):
     def sig(self):
         return self.interface_node.type2sig(self.ext_type)
 
+
 class DefaultTypeNode(NodeBase):
     def __init__(self, csymbol, type_sig):
         NodeBase.__init__(self)
@@ -171,13 +173,14 @@ class MethodNode(NodeBase):
     def __init__(self, parent):
         NodeBase.__init__(self)
         self.parent = parent
-
         self.name = None
         self.csymbol = None
         self.qname = None
         self.condition = ""
         self.params = []
-
+        self.num_in_args = 0
+        self.num_out_args = 0
+        
     def handle(self, node):
         self.name = node.getAttribute('name')
         self.csymbol = node.getAttribute('csymbol')
@@ -199,6 +202,11 @@ class MethodNode(NodeBase):
 
         if p.ext_type == '':
             p.ext_type = p.type;
+
+        if p.direction == 'in':
+            self.num_in_args = self.num_in_args + 1
+        if p.direction == 'out':
+            self.num_out_args = self.num_out_args + 1
             
         hint = node.getAttribute('hint')
         if hint != None and hint != '':
@@ -206,6 +214,15 @@ class MethodNode(NodeBase):
             
         self.params.append(p)
 
+    def introspect_sig(self):
+        method_sig = ''
+        for p in self.params:
+            if p.direction != 'bind':
+                param_sig = self.parent.type2sig(p.ext_type)
+                method_sig = method_sig + '%s\\0%s\\0%s\\0' % (p.direction, param_sig, p.name)
+
+        return method_sig
+
     def sig(self):
         method_sig = ''
         for p in self.params:
@@ -215,6 +232,15 @@ class MethodNode(NodeBase):
 
         return method_sig
 
+    def sig_of_type(self, type):
+        method_sig = ''
+        for p in self.params:
+            if p.direction == type:
+                param_sig = self.parent.type2sig(p.ext_type)
+                method_sig = method_sig + '%s' % (param_sig, )
+
+        return '(' + method_sig + ')'
+
     def return_type(self):
         ret = 'void'
         for p in self.params:
@@ -230,7 +256,6 @@ class MethodNode(NodeBase):
         return ret
         
 
-
 class SignalNode(NodeBase):
     def __init__(self, parent):
         NodeBase.__init__(self)
@@ -256,11 +281,14 @@ class SignalNode(NodeBase):
 
         if p.ext_type == '':
             p.ext_type = p.type;
+
+        hint = node.getAttribute('hint')
+        if hint != None and hint != '':
+            p.hint = hint.split(',')
         
         self.params.append(p)
 
-
-    def sig(self):
+    def introspect_sig(self):
         method_sig = ''
         for p in self.params:
             param_sig = self.parent.type2sig(p.ext_type)
@@ -268,6 +296,14 @@ class SignalNode(NodeBase):
 
         return method_sig
 
+    def sig(self):
+        method_sig = ''
+        for p in self.params:
+            param_sig = self.parent.type2sig(p.ext_type)
+            method_sig = method_sig + param_sig
+
+        return '(' + method_sig + ')'
+
     def return_type(self):
         ret = 'void'
         for p in self.params:
@@ -312,18 +348,15 @@ class StructNode(NodeBase):
 
         self.fields.append(arg)
 
-
     def sig(self):
         struct_sig = ''
         for f in self.fields:
             field_sig = self.parent.type2sig(f.ext_type)
             struct_sig =  struct_sig + field_sig
 
-        print struct_sig
         return '(' + struct_sig + ')'
 
 
-
 class SequenceNode(NodeBase):
     def __init__(self, parent):
         NodeBase.__init__(self)
@@ -401,6 +434,7 @@ class EnumNode(NodeBase):
     def sig(self):
         return 's'
 
+
 class TypeNode(NodeBase):
     def __init__(self, parent):
         NodeBase.__init__(self)
@@ -419,7 +453,6 @@ class TypeNode(NodeBase):
         sys.exit(1)
 
 
-
 class ImportNode(NodeBase):
     def __init__(self, parent):
         NodeBase.__init__(self)
@@ -450,6 +483,9 @@ if __name__ == '__main__':
     parser.add_option("-l", "--language",
                       dest="language",
                       help="Generate stubs for this language")
+    parser.add_option("-g", "--gio",
+                      action="store_true", dest="gio",
+                      help="Generate GIO based stubs")
     parser.add_option("-c", "--client",
                       action="store_true", dest="client",
                       help="Generate client stubs")
@@ -457,25 +493,28 @@ if __name__ == '__main__':
                       action="store_true", dest="server",
                       help="Generate server stubs"
                       )
-
     (options, args) = parser.parse_args()
 
     templates = []
     directory = os.path.dirname(sys.argv[0])
 
+    brand = "freedesktop"
+    if options.gio:
+        brand = "gio"
+
     if options.language:
         if options.language == 'C':
             header_ext=".h"
         elif options.language == 'C++':
             if options.client:
-                templates.append(directory+"/DBus-client-template.cc")
-                templates.append(directory+"/DBus-client-template.hh")
+                templates.append(directory+"/DBus-client-template-" + brand + ".cc")
+                templates.append(directory+"/DBus-client-template-" + brand + ".hh")
             if options.server:
-                templates.append(directory+"/DBus-template.cc")
-                templates.append(directory+"/DBus-template.hh")
+                templates.append(directory+"/DBus-template-" + brand + ".cc")
+                templates.append(directory+"/DBus-template-" + brand + ".hh")
             header_ext=".hh"
-        elif options.language == 'dbus-glib':
-            templates.append(directory+"/DBus-glib.xml")
+        elif options.language == 'xml':
+            templates.append(directory+"/DBus-xml.xml")
             header_ext=".xml"
         else:
             parser.error("Unsupported language: " + options.language)
