@@ -83,6 +83,8 @@
 #include "OSXGtkMenu.hh"
 #endif
 
+#include "MenuEnums.hh"
+
 //! Constructor.
 /*!
  *  \param gui the main GUI entry point.
@@ -209,7 +211,7 @@ Menus::on_menu_restbreak_now()
 
 
 void
-Menus::set_operation_mode(OperationMode m)
+Menus::on_set_operation_mode(OperationMode m)
 {
   ICore *core = CoreFactory::get_core();
   core->set_operation_mode(m);
@@ -230,7 +232,7 @@ void
 Menus::on_menu_quiet()
 {
   TRACE_ENTER("Menus::on_menu_quiet");
-  set_operation_mode(OPERATION_MODE_QUIET);
+  on_set_operation_mode(OPERATION_MODE_QUIET);
   TRACE_EXIT();
 }
 
@@ -239,7 +241,7 @@ void
 Menus::on_menu_suspend()
 {
   TRACE_ENTER("Menus::on_menu_suspend");
-  set_operation_mode(OPERATION_MODE_SUSPENDED);
+  on_set_operation_mode(OPERATION_MODE_SUSPENDED);
   TRACE_EXIT();
 }
 
@@ -248,7 +250,7 @@ void
 Menus::on_menu_normal()
 {
   TRACE_ENTER("Menus::on_menu_normal");
-  set_operation_mode(OPERATION_MODE_NORMAL);
+  on_set_operation_mode(OPERATION_MODE_NORMAL);
   TRACE_EXIT();
 }
 
