@@ -775,9 +775,9 @@ PreferencesDialog::on_cell_data_compare(const Gtk::TreeModel::iterator& iter1,
 void
 PreferencesDialog::on_autostart_toggled()
 {
+#if defined(PLATFORM_OS_WIN32)
   bool on = autostart_cb->get_active();
 
-#if defined(PLATFORM_OS_WIN32)
   gchar *value = NULL;
 
   if (on)
@@ -923,7 +923,7 @@ PreferencesDialog::on_sound_theme_changed()
   TRACE_ENTER("PreferencesDialog::on_sound_theme_changed");
   int idx = sound_theme_button->get_active_row_number();
 
-  if (idx >= 0 && idx < sound_themes.size())
+  if (idx >= 0 && idx < (int)sound_themes.size())
     {
       SoundPlayer::Theme &theme = sound_themes[idx];
 
