@@ -46,7 +46,7 @@ Session::Session()
 void
 Session::init()
 {
-#if defined(HAVE_DBUSGLIB_GET_PRIVATE) && defined(HAVE_GNOME)
+#if defined(HAVE_DBUSGLIB_GET_PRIVATE) || defined(HAVE_DBUS_GIO)
   init_gnome();
 #endif
 }
@@ -59,45 +59,106 @@ Session::set_idle(bool new_idle)
   bool auto_natural = false;
   IConfigurator *config = CoreFactory::get_configurator();
   config->get_value(GUIConfig::CFG_KEY_BREAK_AUTO_NATURAL % BREAK_ID_REST_BREAK, auto_natural);
+  ICore *core = CoreFactory::get_core();
 
-  if (auto_natural)
+  if (core->get_usage_mode() == USAGE_MODE_READING)
     {
-      TRACE_MSG("Automatic natural break enabled");
-      if (new_idle && !is_idle)
-        {
-          TRACE_MSG("Now idle");
-          ICore *core = CoreFactory::get_core();
-          IBreak *rest_break = core->get_break(BREAK_ID_REST_BREAK);
+      core->force_idle();
+    }
 
-          taking = rest_break->is_taking();
-          TRACE_MSG("taking " << taking);
-          if (!taking)
-            {
-              mode_before_screenlock = core->set_operation_mode(OPERATION_MODE_SUSPENDED, false);
-            }
+  if (new_idle && !is_idle)
+    {
+      TRACE_MSG("Now idle");
+      IBreak *rest_break = core->get_break(BREAK_ID_REST_BREAK);
+      
+      taking = rest_break->is_taking();
+      TRACE_MSG("taking " << taking);
+      if (!taking)
+        {
+          core->set_operation_mode_override( OPERATION_MODE_SUSPENDED, "screensaver" );
         }
-      else if (!new_idle && is_idle && !taking)
+    }
+  else if (!new_idle && is_idle && !taking)
+    {
+      TRACE_MSG("No longer idle");
+      core->remove_operation_mode_override( "screensaver" );
+      
+      if (auto_natural)
         {
-          TRACE_MSG("No longer idle");
-          ICore *core = CoreFactory::get_core();
+          TRACE_MSG("Automatic natural break enabled");
           IBreak *rest_break = core->get_break(BREAK_ID_REST_BREAK);
-
-          core->set_operation_mode(mode_before_screenlock, false);
-          if (rest_break->get_elapsed_idle_time() < rest_break->get_auto_reset()
+          
+          if (core->get_operation_mode() == OPERATION_MODE_NORMAL &&
+              rest_break->get_elapsed_idle_time() < rest_break->get_auto_reset()
               && rest_break->is_enabled()
               && !rest_break->is_taking())
             {
-              core->force_break(BREAK_ID_REST_BREAK, BREAK_HINT_NATURAL_BREAK);
+              bool overdue = (rest_break->get_limit() < rest_break->get_elapsed_time());
+              
+              if (overdue)
+                {
+                  core->force_break(BREAK_ID_REST_BREAK, BREAK_HINT_NONE);
+                }
+              else
+                {
+                  core->force_break(BREAK_ID_REST_BREAK, BREAK_HINT_NATURAL_BREAK);
+                }
             }
         }
     }
-  
+
   is_idle = new_idle;
   TRACE_EXIT();
 }
 
+#if defined(HAVE_DBUS_GIO)
+
+void
+Session::on_signal(GDBusProxy *proxy, gchar *sender_name, gchar *signal_name, GVariant *parameters, gpointer user_data)
+{
+  (void) proxy;
+  (void) sender_name;
+  
+  Session *self = (Session *)user_data;
+  int session_status;
+
+  if (g_strcmp0(signal_name, "StatusChanged") == 0)
+    {
+      g_variant_get(parameters, "(u)", &session_status);
+      self->set_idle(session_status == 3);
+    }
+}
+
+      
+void
+Session::init_gnome()
+{
+  TRACE_ENTER("Session::init_gnome");
+	GError *error = NULL;
+
+  GDBusProxy *proxy = g_dbus_proxy_new_for_bus_sync(G_BUS_TYPE_SESSION,
+                                                    G_DBUS_PROXY_FLAGS_NONE,
+                                                    NULL,
+                                                    "org.gnome.SessionManager",
+                                                    "/org/gnome/SessionManager/Presence",
+                                                    "org.gnome.SessionManager.Presence",
+                                                    NULL,
+                                                    &error);
+
+  if (error != NULL)
+    {
+      TRACE_MSG("Error: " << error->message);
+      g_error_free(error);
+    }
+
+  if (error == NULL && proxy != NULL)
+    {
+      g_signal_connect(proxy, "g-signal", G_CALLBACK(on_signal), this);
+    }
+}
+
+#elif defined(HAVE_DBUSGLIB_GET_PRIVATE)
 
-#if defined(HAVE_DBUSGLIB_GET_PRIVATE) && defined(HAVE_GNOME)
 static void
 status_changed_cb(DBusGProxy *proxy, int session_status, void *data)
 {
@@ -123,7 +184,7 @@ Session::init_gnome()
       g_error_free(err);
       return;
     }
-  
+
   proxy = dbus_g_proxy_new_for_name(connection,
                                     "org.gnome.SessionManager",
                                     "/org/gnome/SessionManager/Presence",
