@@ -1,6 +1,6 @@
 // TimerBoxGtkView.cc --- Timers Widgets
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2011, 2012 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -49,8 +49,9 @@
 
 
 //! Constructor.
-TimerBoxGtkView::TimerBoxGtkView(Menus::MenuKind menu) :
+TimerBoxGtkView::TimerBoxGtkView(Menus::MenuKind menu, bool transparent) :
   menu(menu),
+  transparent(transparent),
   reconfigure(true),
   labels(NULL),
   bars(NULL),
@@ -62,7 +63,8 @@ TimerBoxGtkView::TimerBoxGtkView(Menus::MenuKind menu) :
   table_columns(-1),
   table_reverse(false),
   visible_count(-1),
-  rotation(0)
+  rotation(0),
+  sheep_only(false)
 {
   init();
 }
@@ -136,10 +138,10 @@ TimerBoxGtkView::init()
                              Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);
 
   sheep_eventbox->property_visible_window() = false;
-  
+
   string sheep_file = Util::complete_directory("workrave-icon-medium.png", Util::SEARCH_PATH_IMAGES);
   sheep = Gtk::manage(new Gtk::Image(sheep_file));
-  GUI::get_instance()->get_tooltips()->set_tip(*sheep_eventbox, "Workrave");
+  sheep_eventbox->set_tooltip_text("Workrave");
 
   sheep_eventbox->add(*sheep);
 
@@ -184,12 +186,11 @@ TimerBoxGtkView::init_widgets()
           b->set_relief(Gtk::RELIEF_NONE);
           b->set_border_width(0);
           b->add(*Gtk::manage(img));
-    
-          tooltips = Gtk::manage( new Gtk::Tooltips() );
-          tooltips->set_tip( *b, _("Take rest break now") );
-          tooltips->enable();
 
-          Menus *menus = Menus::get_instance();
+          b->set_tooltip_text(_("Take rest break now"));
+
+          IGUI *gui = GUI::get_instance();
+          Menus *menus = gui->get_menus();
 
 	        b->signal_clicked().connect(sigc::mem_fun(*menus, &Menus::on_menu_restbreak_now));
           b->button_pressed.connect(sigc::mem_fun(*this,
@@ -213,6 +214,24 @@ TimerBoxGtkView::init_widgets()
 }
 
 
+int
+TimerBoxGtkView::get_number_of_timers() const
+{
+  int number_of_timers = 0;
+  if (!sheep_only)
+    {
+      for (int i = 0; i < BREAK_ID_SIZEOF; i++)
+        {
+          if (new_content[i] != BREAK_ID_NONE)
+            {
+              number_of_timers++;
+            }
+        }
+    }
+  return number_of_timers;
+}
+
+
 //! Initializes the applet.
 void
 TimerBoxGtkView::init_table()
@@ -220,14 +239,7 @@ TimerBoxGtkView::init_table()
   TRACE_ENTER("TimerBoxGtkView::init_table");
 
   // Compute number of visible breaks.
-  int number_of_timers = 0;
-  for (int i = 0; i < BREAK_ID_SIZEOF; i++)
-    {
-      if (new_content[i] != BREAK_ID_NONE)
-        {
-          number_of_timers++;
-        }
-    }
+  int number_of_timers = get_number_of_timers();
   TRACE_MSG("number_of_timers = " << number_of_timers);
 
   // Compute table dimensions.
@@ -246,11 +258,18 @@ TimerBoxGtkView::init_table()
 
   Gtk::Requisition label_size;
   Gtk::Requisition bar_size;
-
-  labels[0]->size_request(label_size);
-
   Gtk::Requisition my_size;
+
+#ifdef HAVE_GTK3
+  GtkRequisition natural_size;
+  labels[0]->get_preferred_size(label_size, natural_size);
+  get_preferred_size(my_size, natural_size);
+  TRACE_MSG("my_size = " << my_size.width << " " << my_size.height);
+  TRACE_MSG("natural_size = " << natural_size.width << " " << natural_size.height);
+#else
+  labels[0]->size_request(label_size);
   size_request(my_size);
+#endif
 
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
@@ -258,6 +277,8 @@ TimerBoxGtkView::init_table()
     }
 
   bars[0]->get_preferred_size(bar_size.width, bar_size.height);
+  TRACE_MSG("bar_size = " << bar_size.width << " " << bar_size.height);
+  TRACE_MSG("label_size = " << label_size.width << " " << label_size.height);
 
   if (size == -1 && (orientation == ORIENTATION_LEFT))
     {
@@ -274,13 +295,9 @@ TimerBoxGtkView::init_table()
         {
           set_size_request(-1, tsize);
         }
+      TRACE_MSG("size request = " << tsize);
     }
 
-  TRACE_MSG("size:" << size << " tsize:" << tsize << " orienation:" << orientation);
-  TRACE_MSG("mysize width:" << my_size.width << " height:" << my_size.height);
-  TRACE_MSG("bar width:" << bar_size.width << " height:" << bar_size.height);
-  TRACE_MSG("label width:" << label_size.width << " height:" << label_size.height);
-
   if (orientation == ORIENTATION_LEFT || orientation == ORIENTATION_RIGHT)
     {
       if (tsize > bar_size.width + label_size.width + 8)
@@ -310,6 +327,7 @@ TimerBoxGtkView::init_table()
         }
       if (rows <= 0)
         {
+          TRACE_MSG("too small: rows");
           rows = 1;
         }
     }
@@ -318,6 +336,7 @@ TimerBoxGtkView::init_table()
       rows = tsize / (bar_size.height);
       if (rows <= 0)
         {
+          TRACE_MSG("too small: rows");
           rows = 1;
         }
 
@@ -378,6 +397,7 @@ TimerBoxGtkView::init_table()
   // Add sheep.
   if (number_of_timers == 0 && visible_count != 0)
     {
+      TRACE_MSG("add sheep");
       attach(*sheep_eventbox, 0, 2, 0, 1, Gtk::FILL, Gtk::SHRINK);
     }
 
@@ -427,6 +447,13 @@ TimerBoxGtkView::init_table()
   visible_count = number_of_timers;
 
   show_all();
+
+#ifdef HAVE_GTK3
+  get_preferred_size(my_size, natural_size);
+  TRACE_MSG("my_size = " << my_size.width << " " << my_size.height);
+  TRACE_MSG("natural_size = " << natural_size.width << " " << natural_size.height);
+#endif
+  
   TRACE_EXIT();
 }
 
@@ -467,8 +494,7 @@ TimerBoxGtkView::set_time_bar(BreakId id,
 void
 TimerBoxGtkView::set_tip(string tip)
 {
-  Gtk::Tooltips *tt = GUI::get_instance()->get_tooltips();
-  tt->set_tip(*sheep_eventbox, tip.c_str());
+  sheep_eventbox->set_tooltip_text(tip.c_str());
 }
 
 
@@ -522,6 +548,25 @@ TimerBoxGtkView::set_enabled(bool enabled)
 }
 
 
+void
+TimerBoxGtkView::set_sheep_only(bool sheep_only)
+{
+  TRACE_ENTER_MSG("TimerBoxGtkView::set_sheep_only", sheep_only);
+  if (this->sheep_only != sheep_only)
+    {
+      this->sheep_only = sheep_only;
+      reconfigure = true;
+      update_view();
+    }
+  TRACE_EXIT();
+}
+
+bool
+TimerBoxGtkView::is_sheep_only() const
+{
+  return sheep_only || get_number_of_timers() == 0;
+}
+
 //! User pressed some mouse button in the main window.
 bool
 TimerBoxGtkView::on_restbreak_button_press_event(int button)
@@ -530,10 +575,27 @@ TimerBoxGtkView::on_restbreak_button_press_event(int button)
 
   if (button == 3 && menu != Menus::MENU_NONE)
     {
-      Menus::get_instance()->popup(menu,
-                                   0 /*event->button */, 0);
+      IGUI *gui = GUI::get_instance();
+      Menus *menus = gui->get_menus();
+      menus->popup(menu, 0 /*event->button */, 0);
       ret = true;
     }
 
   return ret;
 }
+
+
+#ifdef HAVE_GTK3
+bool
+TimerBoxGtkView::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
+{
+  if (transparent)
+    {
+      cr->set_source_rgba(0, 0, 0, 0);
+      cr->set_operator(Cairo::OPERATOR_SOURCE);
+      cr->paint();
+    };
+
+  return Gtk::Widget::on_draw(cr);
+}
+#endif
