@@ -1,6 +1,6 @@
 // X11SystrayAppletWindow.cc --- Applet info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011, 2012 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011, 2012, 2013 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -113,7 +113,7 @@ X11SystrayAppletWindow::activate_applet()
   if (applet_active)
     {
       TRACE_EXIT();
-      return APPLET_STATE_VISIBLE;
+      return APPLET_STATE_ACTIVE;
     }
 
   tray_icon = wrgtk_tray_icon_new("Workrave Tray Icon");
@@ -254,7 +254,7 @@ X11SystrayAppletWindow::on_embedded()
 #endif
     }
 
-  state_changed_signal.emit(AppletWindow::APPLET_STATE_VISIBLE);
+  state_changed_signal.emit(AppletWindow::APPLET_STATE_ACTIVE);
   TRACE_EXIT();
 }
 
