@@ -34,6 +34,7 @@
 
 #include "crashlog.h"
 #include "dll_hell.h"
+#include "W32ActiveSetup.hh"
 #endif
 
 extern "C" int run(int argc, char **argv);
@@ -41,6 +42,9 @@ extern "C" int run(int argc, char **argv);
 int
 run(int argc, char **argv)
 {
+#ifdef PLATFORM_OS_WIN32
+    W32ActiveSetup::update_all();
+#endif
 
 #if defined(PLATFORM_OS_WIN32) && !defined(PLATFORM_OS_WIN32_NATIVE)
 	SetUnhandledExceptionFilter(exception_filter);
@@ -50,11 +54,11 @@ run(int argc, char **argv)
   __try1(exception_handler);
 #endif
 #endif
-  
-#ifdef TRACING 
+
+#ifdef TRACING
   Debug::init();
 #endif
-  
+
   GUI *gui = new GUI(argc, argv);
 
 #if defined(PLATFORM_OS_WIN32)
@@ -71,7 +75,7 @@ run(int argc, char **argv)
   __except1;
 #endif
 #endif
-  
+
   return 0;
 }
 
@@ -98,7 +102,7 @@ int WINAPI WinMain (HINSTANCE hInstance,
   (void) iCmdShow;
 
   char *argv[] = { szCmdLine };
-  
+
   // InnoSetup: [...] requires that you add code to your application
   // which creates a mutex with the name you specify in this
   // directive.
